Express Function as Service Middleware
======


Usage
-----
Load functions: 
```js
app.use(func(main, [hello], '/functions')).listen(80);
```

request by GET/POST: 
```js
request.post('localhost:80')
    .send({action:'hello'})
    .then(response => {
        console.log(response.text)
    })
```

Example (One function)
-----
```js
const func = require('express-function')

app.use(func(main)).listen(80);

function main() {
    return `ok`
}
```
GET localhost ok  


Example (Multiple functions)
-----
```js
const func = require('express-function')
app.use(func(main, hello)).listen(80)

async function main() {
    return `ok`
}

async function hello() {
    return `world`
}
```
GET localhost?action=hello word


Example (File functions)
-----
/index.js
```js
const func = require('express-function')
app.use(func('/functions')).listen(80)
```

/functions/foo.js
```js
async function foo() {
    return `bar`
}
```
GET localhost?action=foo bar
