const app        = require('express').Router()
const bodyParser = require('body-parser')
const nofavicon  = require('express-no-favicons')
const _          = require('lodash')
const glob       = require('glob')
const cors       = require('cors')
const path       = require('path')

app.use(cors({origin:true, credentials:true}))
app.use(nofavicon())
app.use(bodyParser.urlencoded({limit:'50mb', parameterLimit:100000, extended:true}))
app.use(bodyParser.json({limit:'50mb', extended:true}))

module.exports = (...funcs) => {

    app.use( async (req, res) => {

        let actions = [];
        let action  = null;
        let params  = Object.assign(req.query, req.body)

        // default dir
        if(funcs.length == 0)
            funcs = [path.join(path.dirname(module.parent.filename), '/functions')]

        // load actions
        funcs.forEach(func => {
            if(_.isFunction(func))
                actions.push(func)
            if(_.isObject(func))
                Object.values(func).forEach(fn => actions.push(fn))                
            if(_.isString(func)) 
                glob.sync(func+'/**/*.js').forEach(file => {
                    Object.values(require(file)).forEach(fn => actions.push(fn))
                })
        })

        // find action
        if( _.has(params, `action`) && params.action == `index` )
            return res.status(200).send(actions.map(action => action.name).join(`<br>`))        
        else if( _.has(params, `action`) )
            action = _(actions).filter(function(action) { return action.name == params.action }).first()
        else
            action = _(actions).first();   

        if(!action)
            return res.status(404).send(`Function Not Found`)

        // exec action
        try {
            let result = await action(_.omit(params, `action`))
            return res.status(200).send(result)
        } catch (error) {
            return res.status(500).send(error.message)
        }   

    })       

    return app

}